@@ -14,23 +14,44 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
+import os
 from abc import ABCMeta, abstractmethod
 
 class SerDe:
+  """
+  Implementations of this abstract class serve to translate between a
+  NodeRegister and it's off-memory/persistant representation on the file system
+  or elsewhere.
+  """
+  
   __metaclass__ = ABCMeta
   
   @abstractmethod
   def serialize(self, node_register):
+    """
+    This method must be implemented in the child class to translate a provided
+    NodeRegister instance to it's target off-memory representation.
+    """
     pass
   
   @abstractmethod
   def deserialize(self, proc_file, restart=False):
+    """
+    This method must be implemented in teh child class to translate it's
+    off-memory representation to a NodeRegister instance.
+    """
     pass
   
   def save_to_file(self, filepath, node_register):
+    tmp  = filepath+'.tmp'
+    perm = filepath
+    
     try:
-      with open(filepath, 'w') as file:
+      with open(tmp, 'w') as file:
         file.write(self.serialize(node_register))
+      if os.path.isfile(perm):
+        os.unlink(perm)
+      os.rename(tmp, perm)
     except Exception:
       print('Failure in save_to_file()')
       raise
\ No newline at end of file
